@@ -30,7 +30,7 @@
  *
  */
 
-#include "squid-old.h"
+#include "squid.h"
 #include "cbdata.h"
 #include "CacheManager.h"
 #include "DnsLookupDetails.h"
@@ -38,13 +38,20 @@
 #include "ip/Address.h"
 #include "ip/tools.h"
 #include "ipcache.h"
+#include "Mem.h"
 #include "mgr/Registration.h"
+#include "rfc3596.h"
+#include "SquidConfig.h"
 #include "SquidDns.h"
 #include "SquidTime.h"
 #include "StatCounters.h"
 #include "Store.h"
 #include "wordlist.h"
 
+#if SQUID_SNMP
+#include "snmp_core.h"
+#endif
+
 /**
  \defgroup IPCacheAPI IP Cache API
  \ingroup Components
@@ -106,8 +113,8 @@ public:
     dlink_node lru;
     unsigned short locks;
     struct {
-        unsigned int negcached:1;
-        unsigned int fromhosts:1;
+        bool negcached;
+        bool fromhosts;
     } flags;
 
     int age() const; ///< time passed since request_time or -1 if unknown
@@ -175,8 +182,6 @@ ipcache_entry::age() const
     return request_time.tv_sec ? tvSubMsec(request_time, current_time) : -1;
 }
 
-
-
 /**
  \ingroup IPCacheInternal
  *
@@ -186,12 +191,12 @@ static void
 ipcacheRelease(ipcache_entry * i, bool dofree)
 {
     if (!i) {
-        debugs(14, 0, "ipcacheRelease: Releasing entry with i=<NULL>");
+        debugs(14, DBG_CRITICAL, "ipcacheRelease: Releasing entry with i=<NULL>");
         return;
     }
 
     if (!i || !i->hash.key) {
-        debugs(14, 0, "ipcacheRelease: Releasing entry without hash link!");
+        debugs(14, DBG_CRITICAL, "ipcacheRelease: Releasing entry without hash link!");
         return;
     }
 
@@ -255,7 +260,7 @@ ipcache_purgelru(void *voidnotused)
 
         ipcacheRelease(i);
 
-        removed++;
+        ++removed;
     }
 
     debugs(14, 9, "ipcache_purgelru: removed " << removed << " entries");
@@ -371,7 +376,7 @@ ipcacheParse(ipcache_entry *i, const char *inbuf)
     i->addrs.count = 0;
 
     if (inbuf == NULL) {
-        debugs(14, 1, "ipcacheParse: Got <NULL> reply");
+        debugs(14, DBG_IMPORTANT, "ipcacheParse: Got <NULL> reply");
         i->error_message = xstrdup("Internal Error");
         return -1;
     }
@@ -381,7 +386,7 @@ ipcacheParse(ipcache_entry *i, const char *inbuf)
     token = strtok(buf, w_space);
 
     if (NULL == token) {
-        debugs(14, 1, "ipcacheParse: expecting result, got '" << inbuf << "'");
+        debugs(14, DBG_IMPORTANT, "ipcacheParse: expecting result, got '" << inbuf << "'");
 
         i->error_message = xstrdup("Internal Error");
         return -1;
@@ -395,7 +400,7 @@ ipcacheParse(ipcache_entry *i, const char *inbuf)
     }
 
     if (0 != strcmp(token, "$addr")) {
-        debugs(14, 1, "ipcacheParse: expecting '$addr', got '" << inbuf << "' in response to '" << name << "'");
+        debugs(14, DBG_IMPORTANT, "ipcacheParse: expecting '$addr', got '" << inbuf << "' in response to '" << name << "'");
 
         i->error_message = xstrdup("Internal Error");
         return -1;
@@ -404,7 +409,7 @@ ipcacheParse(ipcache_entry *i, const char *inbuf)
     token = strtok(NULL, w_space);
 
     if (NULL == token) {
-        debugs(14, 1, "ipcacheParse: expecting TTL, got '" << inbuf << "' in response to '" << name << "'");
+        debugs(14, DBG_IMPORTANT, "ipcacheParse: expecting TTL, got '" << inbuf << "' in response to '" << name << "'");
 
         i->error_message = xstrdup("Internal Error");
         return -1;
@@ -423,23 +428,23 @@ ipcacheParse(ipcache_entry *i, const char *inbuf)
         int j, k;
 
         i->addrs.in_addrs = static_cast<Ip::Address *>(xcalloc(ipcount, sizeof(Ip::Address)));
-        for (int l = 0; l < ipcount; l++)
-            i->addrs.in_addrs[l].SetEmpty(); // perform same init actions as constructor would.
+        for (int l = 0; l < ipcount; ++l)
+            i->addrs.in_addrs[l].setEmpty(); // perform same init actions as constructor would.
         i->addrs.bad_mask = (unsigned char *)xcalloc(ipcount, sizeof(unsigned char));
         memset(i->addrs.bad_mask, 0, sizeof(unsigned char) * ipcount);
 
-        for (j = 0, k = 0; k < ipcount; k++) {
-            if ( i->addrs.in_addrs[j] = A[k] )
-                j++;
+        for (j = 0, k = 0; k < ipcount; ++k) {
+            if ((i->addrs.in_addrs[j] = A[k]))
+                ++j;
             else
-                debugs(14, 1, "ipcacheParse: Invalid IP address '" << A[k] << "' in response to '" << name << "'");
+                debugs(14, DBG_IMPORTANT, "ipcacheParse: Invalid IP address '" << A[k] << "' in response to '" << name << "'");
         }
 
         i->addrs.count = (unsigned char) j;
     }
 
     if (i->addrs.count <= 0) {
-        debugs(14, 1, "ipcacheParse: No addresses in response to '" << name << "'");
+        debugs(14, DBG_IMPORTANT, "ipcacheParse: No addresses in response to '" << name << "'");
         return -1;
     }
 
@@ -468,7 +473,7 @@ ipcacheParse(ipcache_entry *i, const rfc1035_rr * answers, int nr, const char *e
     int cname_found = 0;
 
     i->expires = squid_curtime + Config.negativeDnsTtl;
-    i->flags.negcached = 1;
+    i->flags.negcached = true;
     safe_free(i->addrs.in_addrs);
     assert(i->addrs.in_addrs == NULL);
     safe_free(i->addrs.bad_mask);
@@ -492,32 +497,32 @@ ipcacheParse(ipcache_entry *i, const rfc1035_rr * answers, int nr, const char *e
     debugs(14, 3, "ipcacheParse: " << nr << " answers for '" << name << "'");
     assert(answers);
 
-    for (k = 0; k < nr; k++) {
+    for (k = 0; k < nr; ++k) {
 
         if (Ip::EnableIpv6 && answers[k].type == RFC1035_TYPE_AAAA) {
             if (answers[k].rdlength != sizeof(struct in6_addr)) {
-                debugs(14, 1, "ipcacheParse: Invalid IPv6 address in response to '" << name << "'");
+                debugs(14, DBG_IMPORTANT, "ipcacheParse: Invalid IPv6 address in response to '" << name << "'");
                 continue;
             }
-            na++;
-            IpcacheStats.rr_aaaa++;
+            ++na;
+            ++IpcacheStats.rr_aaaa;
             continue;
         }
 
         if (answers[k].type == RFC1035_TYPE_A) {
             if (answers[k].rdlength != sizeof(struct in_addr)) {
-                debugs(14, 1, "ipcacheParse: Invalid IPv4 address in response to '" << name << "'");
+                debugs(14, DBG_IMPORTANT, "ipcacheParse: Invalid IPv4 address in response to '" << name << "'");
                 continue;
             }
-            na++;
-            IpcacheStats.rr_a++;
+            ++na;
+            ++IpcacheStats.rr_a;
             continue;
         }
 
         /* With A and AAAA, the CNAME does not necessarily come with additional records to use. */
         if (answers[k].type == RFC1035_TYPE_CNAME) {
             cname_found=1;
-            IpcacheStats.rr_cname++;
+            ++IpcacheStats.rr_cname;
             continue;
         }
 
@@ -525,19 +530,19 @@ ipcacheParse(ipcache_entry *i, const rfc1035_rr * answers, int nr, const char *e
         debugs(14, 9, HERE << "Unknown RR type received: type=" << answers[k].type << " starting at " << &(answers[k]) );
     }
     if (na == 0) {
-        debugs(14, 1, "ipcacheParse: No Address records in response to '" << name << "'");
+        debugs(14, DBG_IMPORTANT, "ipcacheParse: No Address records in response to '" << name << "'");
         i->error_message = xstrdup("No Address records");
         if (cname_found)
-            IpcacheStats.cname_only++;
+            ++IpcacheStats.cname_only;
         return 0;
     }
 
     i->addrs.in_addrs = static_cast<Ip::Address *>(xcalloc(na, sizeof(Ip::Address)));
-    for (int l = 0; l < na; l++)
-        i->addrs.in_addrs[l].SetEmpty(); // perform same init actions as constructor would.
+    for (int l = 0; l < na; ++l)
+        i->addrs.in_addrs[l].setEmpty(); // perform same init actions as constructor would.
     i->addrs.bad_mask = (unsigned char *)xcalloc(na, sizeof(unsigned char));
 
-    for (j = 0, k = 0; k < nr; k++) {
+    for (j = 0, k = 0; k < nr; ++k) {
 
         if (answers[k].type == RFC1035_TYPE_A) {
             if (answers[k].rdlength != sizeof(struct in_addr))
@@ -548,7 +553,7 @@ ipcacheParse(ipcache_entry *i, const rfc1035_rr * answers, int nr, const char *e
             i->addrs.in_addrs[j] = temp;
 
             debugs(14, 3, "ipcacheParse: " << name << " #" << j << " " << i->addrs.in_addrs[j]);
-            j++;
+            ++j;
 
         } else if (Ip::EnableIpv6 && answers[k].type == RFC1035_TYPE_AAAA) {
             if (answers[k].rdlength != sizeof(struct in6_addr))
@@ -559,7 +564,7 @@ ipcacheParse(ipcache_entry *i, const rfc1035_rr * answers, int nr, const char *e
             i->addrs.in_addrs[j] = temp;
 
             debugs(14, 3, "ipcacheParse: " << name << " #" << j << " " << i->addrs.in_addrs[j] );
-            j++;
+            ++j;
         }
         if (ttl == 0 || (int) answers[k].ttl < ttl)
             ttl = answers[k].ttl;
@@ -580,7 +585,7 @@ ipcacheParse(ipcache_entry *i, const rfc1035_rr * answers, int nr, const char *e
 
     i->expires = squid_curtime + ttl;
 
-    i->flags.negcached = 0;
+    i->flags.negcached = false;
 
     return i->addrs.count;
 }
@@ -590,19 +595,19 @@ ipcacheParse(ipcache_entry *i, const rfc1035_rr * answers, int nr, const char *e
 /// \ingroup IPCacheInternal
 static void
 #if USE_DNSHELPER
-ipcacheHandleReply(void *data, char *reply)
+ipcacheHandleReply(void *data, const HelperReply &reply)
 #else
 ipcacheHandleReply(void *data, const rfc1035_rr * answers, int na, const char *error_message)
 #endif
 {
     ipcache_entry *i;
     static_cast<generic_cbdata *>(data)->unwrap(&i);
-    IpcacheStats.replies++;
+    ++IpcacheStats.replies;
     const int age = i->age();
     statCounter.dns.svcTime.count(age);
 
 #if USE_DNSHELPER
-    ipcacheParse(i, reply);
+    ipcacheParse(i, reply.other().content());
 #else
 
     int done = ipcacheParse(i, answers, na, error_message);
@@ -640,11 +645,11 @@ ipcache_nbgethostbyname(const char *name, IPH * handler, void *handlerData)
     const ipcache_addrs *addrs = NULL;
     generic_cbdata *c;
     debugs(14, 4, "ipcache_nbgethostbyname: Name '" << name << "'.");
-    IpcacheStats.requests++;
+    ++IpcacheStats.requests;
 
     if (name == NULL || name[0] == '\0') {
         debugs(14, 4, "ipcache_nbgethostbyname: Invalid name!");
-        IpcacheStats.invalid++;
+        ++IpcacheStats.invalid;
         const DnsLookupDetails details("Invalid hostname", -1); // error, no lookup
         if (handler)
             handler(NULL, details, handlerData);
@@ -653,7 +658,7 @@ ipcache_nbgethostbyname(const char *name, IPH * handler, void *handlerData)
 
     if ((addrs = ipcacheCheckNumeric(name))) {
         debugs(14, 4, "ipcache_nbgethostbyname: BYPASS for '" << name << "' (already numeric)");
-        IpcacheStats.numeric_hits++;
+        ++IpcacheStats.numeric_hits;
         const DnsLookupDetails details(NULL, -1); // no error, no lookup
         if (handler)
             handler(addrs, details, handlerData);
@@ -674,9 +679,9 @@ ipcache_nbgethostbyname(const char *name, IPH * handler, void *handlerData)
         debugs(14, 4, "ipcache_nbgethostbyname: HIT for '" << name << "'");
 
         if (i->flags.negcached)
-            IpcacheStats.negative_hits++;
+            ++IpcacheStats.negative_hits;
         else
-            IpcacheStats.hits++;
+            ++IpcacheStats.hits;
 
         i->handler = handler;
 
@@ -688,7 +693,7 @@ ipcache_nbgethostbyname(const char *name, IPH * handler, void *handlerData)
     }
 
     debugs(14, 5, "ipcache_nbgethostbyname: MISS for '" << name << "'");
-    IpcacheStats.misses++;
+    ++IpcacheStats.misses;
     i = ipcacheCreateEntry(name);
     i->handler = handler;
     i->handlerData = cbdataReference(handlerData);
@@ -710,7 +715,6 @@ ipcacheRegisterWithCacheManager(void)
                         stat_ipcache_get, 0, 1);
 }
 
-
 /**
  \ingroup IPCacheAPI
  *
@@ -728,7 +732,7 @@ ipcache_init(void)
     memset(&static_addrs, '\0', sizeof(ipcache_addrs));
 
     static_addrs.in_addrs = static_cast<Ip::Address *>(xcalloc(1, sizeof(Ip::Address)));
-    static_addrs.in_addrs->SetEmpty(); // properly setup the Ip::Address!
+    static_addrs.in_addrs->setEmpty(); // properly setup the Ip::Address!
     static_addrs.bad_mask = (unsigned char *)xcalloc(1, sizeof(unsigned char));
     ipcache_high = (long) (((float) Config.ipcache.size *
                             (float) Config.ipcache.high) / (float) 100);
@@ -763,7 +767,7 @@ ipcache_gethostbyname(const char *name, int flags)
     ipcache_addrs *addrs;
     assert(name);
     debugs(14, 3, "ipcache_gethostbyname: '" << name  << "', flags=" << std::hex << flags);
-    IpcacheStats.requests++;
+    ++IpcacheStats.requests;
     i = ipcache_get(name);
 
     if (NULL == i) {
@@ -772,11 +776,11 @@ ipcache_gethostbyname(const char *name, int flags)
         ipcacheRelease(i);
         i = NULL;
     } else if (i->flags.negcached) {
-        IpcacheStats.negative_hits++;
+        ++IpcacheStats.negative_hits;
         // ignore i->error_message: the caller just checks IP cache presence
         return NULL;
     } else {
-        IpcacheStats.hits++;
+        ++IpcacheStats.hits;
         i->lastref = squid_curtime;
         // ignore i->error_message: the caller just checks IP cache presence
         return &i->addrs;
@@ -785,11 +789,11 @@ ipcache_gethostbyname(const char *name, int flags)
     /* no entry [any more] */
 
     if ((addrs = ipcacheCheckNumeric(name))) {
-        IpcacheStats.numeric_hits++;
+        ++IpcacheStats.numeric_hits;
         return addrs;
     }
 
-    IpcacheStats.misses++;
+    ++IpcacheStats.misses;
 
     if (flags & IP_LOOKUP_IF_MISS)
         ipcache_nbgethostbyname(name, NULL, NULL);
@@ -805,12 +809,12 @@ ipcacheStatPrint(ipcache_entry * i, StoreEntry * sentry)
     char buf[MAX_IPSTRLEN];
 
     if (!sentry) {
-        debugs(14, 0, HERE << "CRITICAL: sentry is NULL!");
+        debugs(14, DBG_CRITICAL, HERE << "CRITICAL: sentry is NULL!");
         return;
     }
 
     if (!i) {
-        debugs(14, 0, HERE << "CRITICAL: ipcache_entry is NULL!");
+        debugs(14, DBG_CRITICAL, HERE << "CRITICAL: ipcache_entry is NULL!");
         storeAppendPrintf(sentry, "CRITICAL ERROR\n");
         return;
     }
@@ -835,16 +839,16 @@ ipcacheStatPrint(ipcache_entry * i, StoreEntry * sentry)
 
     /** \par
      * Cached entries have IPs listed with a BNF of:   ip-address '-' ('OK'|'BAD') */
-    for (k = 0; k < count; k++) {
+    for (k = 0; k < count; ++k) {
         /* Display tidy-up: IPv6 are so big make the list vertical */
         if (k == 0)
             storeAppendPrintf(sentry, " %45.45s-%3s\n",
-                              i->addrs.in_addrs[k].NtoA(buf,MAX_IPSTRLEN),
+                              i->addrs.in_addrs[k].toStr(buf,MAX_IPSTRLEN),
                               i->addrs.bad_mask[k] ? "BAD" : "OK ");
         else
             storeAppendPrintf(sentry, "%s %45.45s-%3s\n",
                               "                                                         ", /* blank-space indenting IP list */
-                              i->addrs.in_addrs[k].NtoA(buf,MAX_IPSTRLEN),
+                              i->addrs.in_addrs[k].toStr(buf,MAX_IPSTRLEN),
                               i->addrs.bad_mask[k] ? "BAD" : "OK ");
     }
 }
@@ -983,11 +987,11 @@ static void
 ipcacheUnlockEntry(ipcache_entry * i)
 {
     if (i->locks < 1) {
-        debugs(14, 1, "WARNING: ipcacheEntry unlocked with no lock! locks=" << i->locks);
+        debugs(14, DBG_IMPORTANT, "WARNING: ipcacheEntry unlocked with no lock! locks=" << i->locks);
         return;
     }
 
-    i->locks--;
+    -- i->locks;
 
     if (ipcacheExpiredEntry(i))
         ipcacheRelease(i);
@@ -1011,7 +1015,7 @@ ipcacheCycleAddr(const char *name, ipcache_addrs * ia)
         ia = &i->addrs;
     }
 
-    for (k = 0; k < ia->count; k++) {
+    for (k = 0; k < ia->count; ++k) {
         if (++ia->cur == ia->count)
             ia->cur = 0;
 
@@ -1023,7 +1027,7 @@ ipcacheCycleAddr(const char *name, ipcache_addrs * ia)
         /* All bad, reset to All good */
         debugs(14, 3, "ipcacheCycleAddr: Changing ALL " << name << " addrs from BAD to OK");
 
-        for (k = 0; k < ia->count; k++)
+        for (k = 0; k < ia->count; ++k)
             ia->bad_mask[k] = 0;
 
         ia->badcount = 0;
@@ -1054,7 +1058,7 @@ ipcacheMarkBadAddr(const char *name, const Ip::Address &addr)
 
     ia = &i->addrs;
 
-    for (k = 0; k < (int) ia->count; k++) {
+    for (k = 0; k < (int) ia->count; ++k) {
         if (addr == ia->in_addrs[k] )
             break;
     }
@@ -1066,8 +1070,7 @@ ipcacheMarkBadAddr(const char *name, const Ip::Address &addr)
     /** Marks the given address as BAD */
     if (!ia->bad_mask[k]) {
         ia->bad_mask[k] = TRUE;
-        ia->badcount++;
-        i->expires = min(squid_curtime + max((time_t)60, Config.negativeDnsTtl), i->expires);
+        ++ia->badcount;
         debugs(14, 2, "ipcacheMarkBadAddr: " << name << " " << addr );
     }
 
@@ -1091,7 +1094,7 @@ ipcacheMarkAllGood(const char *name)
     /* All bad, reset to All good */
     debugs(14, 3, "ipcacheMarkAllGood: Changing ALL " << name << " addrs to OK (" << ia->badcount << "/" << ia->count << " bad)");
 
-    for (k = 0; k < ia->count; k++)
+    for (k = 0; k < ia->count; ++k)
         ia->bad_mask[k] = 0;
 
     ia->badcount = 0;
@@ -1110,7 +1113,7 @@ ipcacheMarkGoodAddr(const char *name, const Ip::Address &addr)
 
     ia = &i->addrs;
 
-    for (k = 0; k < (int) ia->count; k++) {
+    for (k = 0; k < (int) ia->count; ++k) {
         if (addr == ia->in_addrs[k])
             break;
     }
@@ -1123,7 +1126,7 @@ ipcacheMarkGoodAddr(const char *name, const Ip::Address &addr)
 
     ia->bad_mask[k] = FALSE;
 
-    ia->badcount--;
+    -- ia->badcount;
 
     debugs(14, 2, "ipcacheMarkGoodAddr: " << name << " " << addr );
 }
@@ -1188,7 +1191,7 @@ ipcacheAddEntryFromHosts(const char *name, const char *ipaddr)
         if (strchr(ipaddr, ':') && strspn(ipaddr, "0123456789abcdefABCDEF:") == strlen(ipaddr)) {
             debugs(14, 3, "ipcacheAddEntryFromHosts: Skipping IPv6 address '" << ipaddr << "'");
         } else {
-            debugs(14, 1, "ipcacheAddEntryFromHosts: Bad IP address '" << ipaddr << "'");
+            debugs(14, DBG_IMPORTANT, "ipcacheAddEntryFromHosts: Bad IP address '" << ipaddr << "'");
         }
 
         return 1;
@@ -1198,7 +1201,7 @@ ipcacheAddEntryFromHosts(const char *name, const char *ipaddr)
         if (1 == i->flags.fromhosts) {
             ipcacheUnlockEntry(i);
         } else if (i->locks > 0) {
-            debugs(14, 1, "ipcacheAddEntryFromHosts: can't add static entry for locked name '" << name << "'");
+            debugs(14, DBG_IMPORTANT, "ipcacheAddEntryFromHosts: can't add static entry for locked name '" << name << "'");
             return 1;
         } else {
             ipcacheRelease(i);
@@ -1214,7 +1217,7 @@ ipcacheAddEntryFromHosts(const char *name, const char *ipaddr)
     i->addrs.bad_mask = (unsigned char *)xcalloc(1, sizeof(unsigned char));
     i->addrs.in_addrs[0] = ip;
     i->addrs.bad_mask[0] = FALSE;
-    i->flags.fromhosts = 1;
+    i->flags.fromhosts = true;
     ipcacheAddEntry(i);
     ipcacheLockEntry(i);
     return 0;
